@@ -22,14 +22,18 @@
 #include "pindialog.h"
 
 #include <QIntValidator>
+#include <QDebug>
+#include <QDesktopWidget>
 
-#include <KDebug>
-#include <kwindowsystem.h>
+#include <KWindowSystem>
+#include <KIcon>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 #include <ModemManagerQt/manager.h>
 
 PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *parent)
-    : KDialog(parent), m_type(type)
+    : QDialog(parent), m_type(type)
 {
     if (modem) {
         m_udi = modem->uni();
@@ -45,9 +49,8 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
         }
     }
 
-    QWidget *w = new QWidget();
     ui = new Ui::PinWidget();
-    ui->setupUi(w);
+    ui->setupUi(this);
     ui->pin->setPasswordMode(true);
 
     QIntValidator * validator = new QIntValidator(this);
@@ -60,18 +63,16 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     ui->puk->setValidator(validator2);
 
     ui->errorMessage->setHidden(true);
-    QRect desktop = KGlobalSettings::desktopGeometry(topLevelWidget());
+    QRect desktop = QApplication::desktop()->screenGeometry(topLevelWidget());
     setMinimumWidth(qMin(1000, qMax(sizeHint().width(), desktop.width() / 4)));
 
-    pixmapLabel = new QLabel(mainWidget());
+    pixmapLabel = new QLabel(this);
     pixmapLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     ui->gridLayout->addWidget(pixmapLabel, 0, 0);
     pixmapLabel->setPixmap(KIcon("dialog-password").pixmap(KIconLoader::SizeHuge));
 
-    setButtons(KDialog::Ok | KDialog::Cancel);
-    setDefaultButton(KDialog::Ok);
-    button(KDialog::Ok)->setText(i18nc("As in 'Unlock cell phone with this pin code'", "Unlock"));
-    setMainWidget(w);
+    connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &PinDialog::accept);
+    connect(ui->buttonBox, &QDialogButtonBox::rejected, this, &PinDialog::reject);
 
     if (isPukDialog()) {
         QString pukType;
@@ -147,8 +148,8 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     KWindowSystem::activateWindow(winId());
 
     move((desktop.width() - width()) / 2, (desktop.height() - height()) / 2);
-    connect(ui->chkShowPass, SIGNAL(toggled(bool)), this, SLOT(chkShowPassToggled(bool)));
-    connect(ModemManager::notifier(), SIGNAL(modemRemoved(QString)), SLOT(modemRemoved(QString)));
+    connect(ui->chkShowPass, &QCheckBox::toggled, this, &PinDialog::chkShowPassToggled);
+    connect(ModemManager::notifier(), &ModemManager::Notifier::modemRemoved, this, &PinDialog::modemRemoved);
 }
 
 PinDialog::~PinDialog()
