@@ -74,10 +74,10 @@ public:
     virtual ~SecretAgent();
 
 public Q_SLOTS:
-    virtual NMVariantMapMap GetSecrets(const NMVariantMapMap&, const QDBusObjectPath&, const QString&, const QStringList&, uint);
-    virtual void SaveSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path);
-    virtual void DeleteSecrets(const NMVariantMapMap &, const QDBusObjectPath &);
-    virtual void CancelGetSecrets(const QDBusObjectPath &, const QString &);
+    virtual NMVariantMapMap GetSecrets(const NMVariantMapMap&, const QDBusObjectPath&, const QString&, const QStringList&, uint) Q_DECL_OVERRIDE;
+    virtual void SaveSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path) Q_DECL_OVERRIDE;
+    virtual void DeleteSecrets(const NMVariantMapMap &, const QDBusObjectPath &) Q_DECL_OVERRIDE;
+    virtual void CancelGetSecrets(const QDBusObjectPath &, const QString &) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void dialogAccepted();
@@ -87,7 +87,7 @@ private Q_SLOTS:
     void walletClosed();
 
 private:
-    void processNext();
+    void processNext(bool ignoreWallet = false);
     /**
      * @brief processGetSecrets requests
      * @param request the request we are processing
@@ -95,9 +95,9 @@ private:
      * nomally if it failed to open
      * @return true if the item was processed
      */
-    bool processGetSecrets(SecretsRequest &request) const;
-    bool processSaveSecrets(SecretsRequest &request) const;
-    bool processDeleteSecrets(SecretsRequest &request) const;
+    bool processGetSecrets(SecretsRequest &request, bool ignoreWallet) const;
+    bool processSaveSecrets(SecretsRequest &request, bool ignoreWallet) const;
+    bool processDeleteSecrets(SecretsRequest &request, bool ignoreWallet) const;
     /**
      * @brief useWallet checks if the KWallet system is enabled
      * and tries to open it async.
@@ -114,13 +114,9 @@ private:
     bool hasSecrets(const NMVariantMapMap &connection) const;
     void sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage &message) const;
 
-    mutable bool m_openWalletFailed;
     mutable KWallet::Wallet *m_wallet;
     mutable PasswordDialog *m_dialog;
     QList<SecretsRequest> m_calls;
-
-    void importSecretsFromPlainTextFiles();
-
 };
 
 #endif // PLASMA_NM_SECRET_AGENT_H
