@@ -3,7 +3,6 @@
     Copyright 2009 Will Stephenson <wstephenson@kde.org>
     Copyright 2012 Lamarque V. Souza <lamarque@kde.org>
     Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -35,24 +34,17 @@ class NetworkManagementServicePrivate;
 
 class PLASMA_NM_EXPORT NetworkManagementService : public KDEDModule
 {
-    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmanetworkmanagement")
     Q_OBJECT
     Q_DECLARE_PRIVATE(NetworkManagementService)
 public:
     NetworkManagementService(QObject * parent, const QVariantList&);
     virtual ~NetworkManagementService();
-
-public Q_SLOTS:
-    Q_SCRIPTABLE void init();
-
-Q_SIGNALS:
-    Q_SCRIPTABLE void registered();
-
 private Q_SLOTS:
-    void slotRegistered(const QDBusObjectPath &path);
-
+   void finishInitialization();
 private:
-    NetworkManagementServicePrivate * const d_ptr;
+    NetworkManagementServicePrivate * d_ptr;
+
+    void doInitialization();
 };
 
 #endif // PLASMANM_KDED_SERVICE_H
