@@ -21,7 +21,7 @@
 #ifndef PLASMA_NM_IPV6_WIDGET_H
 #define PLASMA_NM_IPV6_WIDGET_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 #include <NetworkManagerQt/Ipv6Setting>
 
 #include "settingwidget.h"
@@ -48,7 +48,7 @@ public:
 
     virtual bool isValid() const;
 
-private slots:
+private Q_SLOTS:
     void slotModeComboChanged(int index);
     void slotRoutesDialog();
 
