@@ -33,34 +33,7 @@
 NetworkModel::NetworkModel(QObject* parent)
     : QAbstractListModel(parent)
 {
-    QHash<int, QByteArray> roles = roleNames();
-    roles[ConnectionDetailsRole] = "ConnectionDetails";
-    roles[ConnectionIconRole] = "ConnectionIcon";
-    roles[ConnectionPathRole] = "ConnectionPath";
-    roles[ConnectionStateRole] = "ConnectionState";
-    roles[DeviceNameRole] = "DeviceName";
-    roles[DevicePathRole] = "DevicePath";
-    roles[DeviceStateRole] = "DeviceState";
-    roles[DuplicateRole] = "Duplicate";
-    roles[ItemUniqueNameRole] = "ItemUniqueName";
-    roles[ItemTypeRole] = "ItemType";
-    roles[LastUsedRole] = "LastUsed";
-    roles[LastUsedDateOnlyRole] = "LastUsedDateOnly";
-    roles[NameRole] = "Name";
-    roles[NspRole] = "Nsp";
-    roles[SectionRole] = "Section";
-    roles[SignalRole] = "Signal";
-    roles[SlaveRole] = "Slave";
-    roles[SsidRole] = "Ssid";
-    roles[SpecificPathRole] = "SpecificPath";
-    roles[SecurityTypeRole] = "SecurityType";
-    roles[SecurityTypeStringRole] = "SecurityTypeString";
-    roles[TimeStampRole] = "TimeStamp";
-    roles[TypeRole] = "Type";
-    roles[UniRole] = "Uni";
-    roles[UuidRole] = "Uuid";
-    roles[VpnState] = "VpnState";
-    setRoleNames(roles);
+    QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.debug = false"));
 
     initialize();
 }
@@ -85,12 +58,12 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->connectionPath();
             case ConnectionStateRole:
                 return item->connectionState();
-            case DeviceNameRole:
-                return item->deviceName();
             case DevicePathRole:
                 return item->devicePath();
             case DeviceStateRole:
                 return item->deviceState();
+            case DownloadRole:
+                return item->download();
             case DuplicateRole:
                 return item->duplicate();
             case ItemUniqueNameRole:
@@ -129,6 +102,8 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->type();
             case UniRole:
                 return item->uni();
+            case UploadRole:
+                return item->upload();
             case UuidRole:
                 return item->uuid();
             case VpnState:
@@ -147,6 +122,40 @@ int NetworkModel::rowCount(const QModelIndex& parent) const
     return m_list.count();
 }
 
+QHash< int, QByteArray > NetworkModel::roleNames() const
+{
+    QHash<int, QByteArray> roles = QAbstractListModel::roleNames();
+    roles[ConnectionDetailsRole] = "ConnectionDetails";
+    roles[ConnectionIconRole] = "ConnectionIcon";
+    roles[ConnectionPathRole] = "ConnectionPath";
+    roles[ConnectionStateRole] = "ConnectionState";
+    roles[DevicePathRole] = "DevicePath";
+    roles[DeviceStateRole] = "DeviceState";
+    roles[DownloadRole] = "Download";
+    roles[DuplicateRole] = "Duplicate";
+    roles[ItemUniqueNameRole] = "ItemUniqueName";
+    roles[ItemTypeRole] = "ItemType";
+    roles[LastUsedRole] = "LastUsed";
+    roles[LastUsedDateOnlyRole] = "LastUsedDateOnly";
+    roles[NameRole] = "Name";
+    roles[NspRole] = "Nsp";
+    roles[SectionRole] = "Section";
+    roles[SignalRole] = "Signal";
+    roles[SlaveRole] = "Slave";
+    roles[SsidRole] = "Ssid";
+    roles[SpecificPathRole] = "SpecificPath";
+    roles[SecurityTypeRole] = "SecurityType";
+    roles[SecurityTypeStringRole] = "SecurityTypeString";
+    roles[TimeStampRole] = "TimeStamp";
+    roles[TypeRole] = "Type";
+    roles[UniRole] = "Uni";
+    roles[UploadRole] = "Upload";
+    roles[UuidRole] = "Uuid";
+    roles[VpnState] = "VpnState";
+
+    return roles;
+}
+
 void NetworkModel::initialize()
 {
     // Initialize existing connections
@@ -214,8 +223,6 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr& device)
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
     connect(device.data(), SIGNAL(ipV6ConfigChanged()),
             SLOT(ipConfigChanged()), Qt::UniqueConnection);
-    connect(device.data(), SIGNAL(ipInterfaceChanged()),
-            SLOT(ipInterfaceChanged()));
     connect(device.data(), SIGNAL(stateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)),
             SLOT(deviceStateChanged(NetworkManager::Device::State,NetworkManager::Device::State,NetworkManager::Device::StateChangeReason)), Qt::UniqueConnection);
 
@@ -237,15 +244,19 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr& device)
 
 #if WITH_MODEMMANAGER_SUPPORT
     else if (device->type() == NetworkManager::Device::Modem) {
-        NetworkManager::ModemDevice::Ptr modemDev = device.objectCast<NetworkManager::ModemDevice>();
-        ModemManager::Modem::Ptr modemNetwork = modemDev->getModemNetworkIface();
-        if (modemDev->isValid()) {
-            connect(modemNetwork.data(), SIGNAL(signalQualityChanged(uint)),
-                    SLOT(gsmNetworkSignalQualityChanged(uint)), Qt::UniqueConnection);
-            connect(modemNetwork.data(), SIGNAL(accessTechnologyChanged(ModemManager::Modem::AccessTechnologies)),
-                    SLOT(gsmNetworkAccessTechnologyChanged(ModemManager::Modem::AccessTechnologies)), Qt::UniqueConnection);
-            connect(modemNetwork.data(), SIGNAL(currentModesChanged()),
-                    SLOT(gsmNetworkCurrentModesChanged()), Qt::UniqueConnection);
+        ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(device->udi());
+        if (modem) {
+            if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+                ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+                if (modemNetwork) {
+                    connect(modemNetwork.data(), SIGNAL(signalQualityChanged(uint)),
+                            SLOT(gsmNetworkSignalQualityChanged(uint)), Qt::UniqueConnection);
+                    connect(modemNetwork.data(), SIGNAL(accessTechnologyChanged(ModemManager::Modem::AccessTechnologies)),
+                            SLOT(gsmNetworkAccessTechnologyChanged(ModemManager::Modem::AccessTechnologies)), Qt::UniqueConnection);
+                    connect(modemNetwork.data(), SIGNAL(currentModesChanged()),
+                            SLOT(gsmNetworkCurrentModesChanged()), Qt::UniqueConnection);
+                }
+            }
         }
     }
 #endif
@@ -303,7 +314,7 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
                 item->setVpnState(state);
             }
             updateItem(item);
-            nmDebug() << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
+            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
         }
     }
 }
@@ -325,7 +336,7 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
         }
         item->setDevicePath(device->uni());
         item->setDeviceState(device->state());
-        nmDebug() << "Item " << item->name() << ": device changed to " << item->devicePath();
+        qCDebug(PLASMA_NM) << "Item " << item->name() << ": device changed to " << item->devicePath();
 #if WITH_MODEMMANAGER_SUPPORT
         if (device->type() == NetworkManager::Device::Modem) {
             ModemManager::ModemDevice::Ptr modemDevice = ModemManager::findModemDevice(device->udi());
@@ -333,7 +344,7 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
                 ModemManager::Modem::Ptr modemInterface = modemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                 if (modemInterface) {
                     item->setSignal(modemInterface->signalQuality().signal);
-                    nmDebug() << "Item " << item->name() << ": signal changed to " << item->signal();
+                    qCDebug(PLASMA_NM) << "Item " << item->name() << ": signal changed to " << item->signal();
                 }
             }
         }
@@ -343,7 +354,7 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
             foreach (NetworkModelItem * secondItem, m_list.returnItems(NetworkItemsList::Ssid, item->ssid())) {
                 if (secondItem->itemType() == NetworkModelItem::AvailableAccessPoint && secondItem->devicePath() == item->devicePath()) {
                     const int row = m_list.indexOf(secondItem);
-                    nmDebug() << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
+                    qCDebug(PLASMA_NM) << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
                     if (row >= 0) {
                         beginRemoveRows(QModelIndex(), row, row);
                         m_list.removeItem(secondItem);
@@ -355,11 +366,9 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
             }
 
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
-            if (wifiDevice) {
-                NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
-                if (wifiNetwork) {
-                    updateFromWirelessNetwork(item, wifiNetwork);
-                }
+            NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(item->ssid());
+            if (wifiNetwork) {
+                updateFromWirelessNetwork(item, wifiNetwork);
             }
         }
 
@@ -368,7 +377,7 @@ void NetworkModel::addAvailableConnection(const QString& connection, const Netwo
             foreach (NetworkModelItem * secondItem, m_list.returnItems(NetworkItemsList::Nsp, item->nsp())) {
                 if (secondItem->itemType() == NetworkModelItem::AvailableNsp && secondItem->devicePath() == item->devicePath()) {
                     const int row = m_list.indexOf(secondItem);
-                    nmDebug() << "Nsp " << secondItem->name() << ": merged to " << item->name() << " connection";
+                    qCDebug(PLASMA_NM) << "Nsp " << secondItem->name() << ": merged to " << item->name() << " connection";
                     if (row >= 0) {
                         beginRemoveRows(QModelIndex(), row, row);
                         m_list.removeItem(secondItem);
@@ -425,7 +434,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr& connecti
         if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
             item->setMode(wirelessSetting->mode());
             item->setSecurityType(NetworkManager::Utils::securityTypeFromConnectionSetting(settings));
-            item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
+            item->setSsid(wirelessSetting->ssid());
         }
 
         if (item->type() == NetworkManager::ConnectionSettings::Wimax) {
@@ -434,11 +443,13 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr& connecti
 
         item->updateDetails();
 
+        connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
+
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(item);
         endInsertRows();
-        nmDebug() << "New connection " << item->name() << " added";
+        qCDebug(PLASMA_NM) << "New connection " << item->name() << " added";
     }
 }
 
@@ -485,11 +496,13 @@ void NetworkModel::addWimaxNsp(const NetworkManager::WimaxNsp::Ptr& nsp, const N
     item->setType(NetworkManager::ConnectionSettings::Wimax);
     item->updateDetails();
 
+    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
+
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
     endInsertRows();
-    nmDebug() << "New wireless network " << item->name() << " added";}
+    qCDebug(PLASMA_NM) << "New wireless network " << item->name() << " added";}
 
 void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr& network, const NetworkManager::WirelessDevice::Ptr& device)
 {
@@ -526,11 +539,13 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->setSecurityType(securityType);
     item->updateDetails();
 
+    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
+
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
     endInsertRows();
-    nmDebug() << "New wireless network " << item->name() << " added";
+    qCDebug(PLASMA_NM) << "New wireless network " << item->name() << " added";
 }
 
 void NetworkModel::checkAndCreateDuplicate(const QString& connection, const NetworkManager::Device::Ptr& device)
@@ -552,6 +567,8 @@ void NetworkModel::checkAndCreateDuplicate(const QString& connection, const Netw
         NetworkModelItem * duplicatedItem = new NetworkModelItem(originalItem);
         duplicatedItem->updateDetails();
 
+        connect(duplicatedItem, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
+
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(duplicatedItem);
@@ -593,7 +610,7 @@ void NetworkModel::accessPointSignalStrengthChanged(int signal)
             if (item->specificPath() == apPtr->uni()) {
                 item->setSignal(signal);
                 updateItem(item);
-                nmDebug() << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
+                qCDebug(PLASMA_NM) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
             }
         }
     }
@@ -615,7 +632,7 @@ void NetworkModel::activeConnectionRemoved(const QString& activeConnection)
         item->setConnectionState(NetworkManager::ActiveConnection::Deactivated);
         item->setVpnState(NetworkManager::VpnConnection::Disconnected);
         updateItem(item);
-        nmDebug() << "Item " << item->name() << ": active connection removed";
+        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection removed";
     }
 }
 
@@ -626,7 +643,7 @@ void NetworkModel::activeConnectionStateChanged(NetworkManager::ActiveConnection
         foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
             item->setConnectionState(state);
             updateItem(item);
-            nmDebug() << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
         }
     }
 }
@@ -650,7 +667,7 @@ void NetworkModel::activeVpnConnectionStateChanged(NetworkManager::VpnConnection
             }
             item->setVpnState(state);
             updateItem(item);
-            nmDebug() << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
         }
     }
 }
@@ -689,7 +706,7 @@ void NetworkModel::availableConnectionDisappeared(const QString& connection)
             item->setDeviceState(NetworkManager::Device::UnknownState);
             item->setSignal(0);
             item->setSpecificPath(QString());
-            nmDebug() << "Item " << item->name() << " removed as available connection";
+            qCDebug(PLASMA_NM) << "Item " << item->name() << " removed as available connection";
             // Check whether the connection is still available as an access point, this happens
             // when we change its properties, like ssid, bssid, security etc.
             if (item->type() == NetworkManager::ConnectionSettings::Wireless && !specificPath.isEmpty()) {
@@ -723,7 +740,7 @@ void NetworkModel::availableConnectionDisappeared(const QString& connection)
             if (item->duplicate()) {
                 const int row = m_list.indexOf(item);
                 if (row >= 0) {
-                    nmDebug() << "Duplicate item " << item->name() << " removed completely";
+                    qCDebug(PLASMA_NM) << "Duplicate item " << item->name() << " removed completely";
                     beginRemoveRows(QModelIndex(), row, row);
                     m_list.removeItem(item);
                     item->deleteLater();
@@ -771,7 +788,7 @@ void NetworkModel::connectionRemoved(const QString& connection)
                 item->setTimestamp(QDateTime());
                 item->setUuid(QString());
                 updateItem(item);
-                nmDebug() << "Item " << item->name() << ": connection removed";
+                qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection removed";
             }
         } else {
             remove = true;
@@ -780,7 +797,7 @@ void NetworkModel::connectionRemoved(const QString& connection)
         if (remove) {
             const int row = m_list.indexOf(item);
             if (row >= 0) {
-                nmDebug() << "Item " << item->name() << " removed completely";
+                qCDebug(PLASMA_NM) << "Item " << item->name() << " removed completely";
                 beginRemoveRows(QModelIndex(), row, row);
                 m_list.removeItem(item);
                 item->deleteLater();
@@ -808,7 +825,7 @@ void NetworkModel::connectionUpdated()
                 wirelessSetting = settings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
                 item->setMode(wirelessSetting->mode());
                 item->setSecurityType(NetworkManager::Utils::securityTypeFromConnectionSetting(settings));
-                item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
+                item->setSsid(wirelessSetting->ssid());
                 // TODO check whether BSSID has changed and update the wireless info
             }
 
@@ -819,7 +836,7 @@ void NetworkModel::connectionUpdated()
             }
 
             updateItem(item);
-            nmDebug() << "Item " << item->name() << ": connection updated";
+            qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection updated";
         }
     }
 }
@@ -851,7 +868,7 @@ void NetworkModel::deviceStateChanged(NetworkManager::Device::State state, Netwo
         foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, device->uni())) {
             item->setDeviceState(state);
             updateItem(item);
-//             nmDebug() << "Item " << item->name() << ": device state changed to " << item->deviceState();
+//             qCDebug(PLASMA_NM) << "Item " << item->name() << ": device state changed to " << item->deviceState();
         }
     }
 }
@@ -864,12 +881,15 @@ void NetworkModel::gsmNetworkAccessTechnologyChanged(ModemManager::Modem::Access
     if (gsmNetwork) {
         foreach (const NetworkManager::Device::Ptr & dev, NetworkManager::networkInterfaces()) {
             if (dev->type() == NetworkManager::Device::Modem) {
-                NetworkManager::ModemDevice::Ptr modem = dev.objectCast<NetworkManager::ModemDevice>();
+                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
                 if (modem) {
-                    if (modem->getModemNetworkIface()->device() == gsmNetwork->device()) {
-                        // TODO store access technology internally?
-                        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
-                            updateItem(item);
+                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
+                            // TODO store access technology internally?
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                                updateItem(item);
+                            }
                         }
                     }
                 }
@@ -884,11 +904,14 @@ void NetworkModel::gsmNetworkCurrentModesChanged()
     if (gsmNetwork) {
         foreach (const NetworkManager::Device::Ptr & dev, NetworkManager::networkInterfaces()) {
             if (dev->type() == NetworkManager::Device::Modem) {
-                NetworkManager::ModemDevice::Ptr modem = dev.objectCast<NetworkManager::ModemDevice>();
+                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
                 if (modem) {
-                    if (modem->getModemNetworkIface()->device() == gsmNetwork->device()) {
-                        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
-                            updateItem(item);
+                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                                updateItem(item);
+                            }
                         }
                     }
                 }
@@ -903,12 +926,15 @@ void NetworkModel::gsmNetworkSignalQualityChanged(uint signal)
     if (gsmNetwork) {
         foreach (const NetworkManager::Device::Ptr & dev, NetworkManager::networkInterfaces()) {
             if (dev->type() == NetworkManager::Device::Modem) {
-                NetworkManager::ModemDevice::Ptr modem = dev.objectCast<NetworkManager::ModemDevice>();
+                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
                 if (modem) {
-                    if (modem->getModemNetworkIface()->device() == gsmNetwork->device()) {
-                        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
-                            item->setSignal(signal);
-                            updateItem(item);
+                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
+                            foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, modem->uni())) {
+                                item->setSignal(signal);
+                                updateItem(item);
+                            }
                         }
                     }
                 }
@@ -916,7 +942,6 @@ void NetworkModel::gsmNetworkSignalQualityChanged(uint signal)
         }
     }
 }
-
 #endif
 
 void NetworkModel::ipConfigChanged()
@@ -926,21 +951,7 @@ void NetworkModel::ipConfigChanged()
     if (device) {
         foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, device->uni())) {
             updateItem(item);
-//             nmDebug() << "Item " << item->name() << ": device ipconfig changed";
-        }
-    }
-}
-
-void NetworkModel::ipInterfaceChanged()
-{
-    NetworkManager::Device * device = qobject_cast<NetworkManager::Device*>(sender());
-    if (device) {
-        foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Device, device->uni())) {
-            if (device->ipInterfaceName().isEmpty()) {
-                item->setDeviceName(device->interfaceName());
-            } else {
-                item->setDeviceName(device->ipInterfaceName());
-            }
+//            qCDebug(PLASMA_NM) << "Item " << item->name() << ": device ipconfig changed";
         }
     }
 }
@@ -949,7 +960,7 @@ void NetworkModel::statusChanged(NetworkManager::Status status)
 {
     Q_UNUSED(status);
 
-    nmDebug() << "NetworkManager state changed to " << status;
+    qCDebug(PLASMA_NM) << "NetworkManager state changed to " << status;
     // This has probably effect only for VPN connections
     foreach (NetworkModelItem * item, m_list.returnItems(NetworkItemsList::Type, NetworkManager::ConnectionSettings::Vpn)) {
         updateItem(item);
@@ -977,7 +988,7 @@ void NetworkModel::wimaxNspDisappeared(const QString& nsp)
             if (item->itemType() == NetworkModelItem::AvailableNsp || item->duplicate()) {
                 const int row = m_list.indexOf(item);
                 if (row >= 0) {
-                    nmDebug() << "Wimax Nsp " << item->name() << " removed completely";
+                    qCDebug(PLASMA_NM) << "Wimax Nsp " << item->name() << " removed completely";
                     beginRemoveRows(QModelIndex(), row, row);
                     m_list.removeItem(item);
                     item->deleteLater();
@@ -990,7 +1001,7 @@ void NetworkModel::wimaxNspDisappeared(const QString& nsp)
                 item->setSpecificPath(QString());
                 item->setSignal(0);
                 updateItem(item);
-                nmDebug() << "Item " << item->name() << ": wimax Nsp removed";
+                qCDebug(PLASMA_NM) << "Item " << item->name() << ": wimax Nsp removed";
             }
         }
     }
@@ -1004,7 +1015,7 @@ void NetworkModel::wimaxNspSignalChanged(uint signal)
             if (item->specificPath() == nspPtr->uni()) {
                 item->setSignal(signal);
                 updateItem(item);
-//              nmDebug() << "Wimax Nsp " << item->name() << ": signal changed to " << item->signal();
+//              qCDebug(PLASMA_NM) << "Wimax Nsp " << item->name() << ": signal changed to " << item->signal();
             }
         }
     }
@@ -1029,7 +1040,7 @@ void NetworkModel::wirelessNetworkDisappeared(const QString& ssid)
             if (item->itemType() == NetworkModelItem::AvailableAccessPoint || item->duplicate()) {
                 const int row = m_list.indexOf(item);
                 if (row >= 0) {
-                    nmDebug() << "Wireless network " << item->name() << " removed completely";
+                    qCDebug(PLASMA_NM) << "Wireless network " << item->name() << " removed completely";
                     beginRemoveRows(QModelIndex(), row, row);
                     m_list.removeItem(item);
                     item->deleteLater();
@@ -1044,7 +1055,7 @@ void NetworkModel::wirelessNetworkDisappeared(const QString& ssid)
                 }
                 item->setSignal(0);
                 updateItem(item);
-                nmDebug() << "Item " << item->name() << ": wireless network removed";
+                qCDebug(PLASMA_NM) << "Item " << item->name() << ": wireless network removed";
             }
         }
     }
@@ -1078,7 +1089,7 @@ void NetworkModel::wirelessNetworkSignalChanged(int signal)
             if (item->specificPath() == networkPtr->referenceAccessPoint()->uni()) {
                 item->setSignal(signal);
                 updateItem(item);
-                nmDebug() << "Wireless network " << item->name() << ": signal changed to " << item->signal();
+//              qCDebug(PLASMA_NM) << "Wireless network " << item->name() << ": signal changed to " << item->signal();
             }
         }
     }
