@@ -23,11 +23,13 @@
 #include "ui_strongswanauth.h"
 #include "nm-strongswan-service.h"
 
-#include <KDialog>
+#include <QDialog>
 #include <KMessageBox>
 #include <QString>
 #include <QProcessEnvironment>
 
+#include <KLocalizedString>
+
 class StrongswanAuthWidgetPrivate
 {
 public:
@@ -94,7 +96,7 @@ void StrongswanAuthWidget::setVisible(bool visible)
 
 void StrongswanAuthWidget::acceptDialog()
 {
-    KDialog *dialog = qobject_cast<KDialog*>(parentWidget());
+    QDialog *dialog = qobject_cast<QDialog*>(parentWidget());
     if (dialog) {
         dialog->accept();
     }
